--[[
AdiRareLocations - Add rare locations into GatherMate2.
Copyright (C) 2013 Adirelle (adirelle@gmail.com)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
--]]

local addonName, addon = ...
local GatherMate = _G.GatherMate2

local frame = CreateFrame("Frame")

local RareDB = {}
local dbType = "Rare Spawn points"
local initialized = {}
local node_ids = {}
local reversed_node_ids
local textures = {}
local MapData = LibStub("LibMapData-1.0")

function frame:CRITERIA_UPDATE()
	local added = false
	for achievementId, npcs in pairs(addon.NPCs) do
		local num = GetAchievementNumCriteria(achievementId)
		if num and num >= 1 then
			local firstTime = not initialized[achievementId]
			for index = 1, num do
				local name, type_, completed, _, _, _, _, npcId = GetAchievementCriteriaInfo(achievementId, index)
				if name and type_ == 0 and npcs[npcId] then
					if completed then
						if not firstTime then
							for mapId, pins in pairs(npcs[npcId]) do
								for i, pin in ipairs(pins) do
									GatherMate:RemoveNode(mapId, pin[2]/100, pin[3]/100, pin[1], dbType)
								end
							end
						end
					else
						if firstTime then
							for mapId, pins in pairs(npcs[npcId]) do
								for i, pin in ipairs(pins) do
									node_ids[name] = npcId
									reversed_node_ids[npcId] = name
									textures[npcId] = "Interface\\AddOns\\AdiRareLocations\\skull"
									GatherMate:AddNode(mapId, pin[2]/100, pin[3]/100, pin[1], dbType, name)
								end
							end
						end
					end

				end
			end
			initialized[achievementId] = true
		end
	end
end
frame.PLAYER_ENTERING_WORLD = frame.CRITERIA_UPDATE

function frame:ADDON_LOADED(_, name)
	if name ~= addonName then return end
	self:UnregisterEvent('ADDON_LOADED')

	GatherMate:RegisterDBType(dbType, RareDB)
	GatherMate.db.profile.show[dbType] = "always"

	GatherMate.nodeTextures[dbType] = textures
	GatherMate.nodeIDs[dbType] = node_ids
	reversed_node_ids = GatherMate:CreateReversedTable(node_ids)
	GatherMate.reverseNodeIDs[dbType] = reversed_node_ids

	frame:RegisterEvent('CRITERIA_UPDATE')
	frame:RegisterEvent('PLAYER_ENTERING_WORLD')
end

frame:SetScript('OnEvent', function(self, event, ...) return self[event](self, event, ...) end)
frame:RegisterEvent('ADDON_LOADED')
